void drawTree(float len, float angle, int iters) {
  String[][] rules = {{"F", "FF-[F--F[F--F]]F+F[F++F[F++F]]"}, {"[", "["}, {"]", "]"}, {"+", "+"}, {"-", "-"}};
  String axiom = "F";
  String computedWord = axiom;
  Stack<TurtlePos> stack = new Stack<>();
  
  //Put the turtle at the bottom
  t.setY(height);
  
  //Compute the new word
  for (int i=0; i<iters; i++) {
    String tempWord = computedWord;
    computedWord = "";
    
    for (int j=0; j<tempWord.length(); j++) {
      char c = tempWord.charAt(j);
      
      for (String[] r : rules) {
        if (c == r[0].charAt(0)) {
          computedWord += r[1];  
        }
      }
    }
  }
  
  //Draw the string, brackets are based on ABOP page 24
  for (char c : computedWord.toCharArray()) {
    if (c == 'F') {
      t.forward(len);
      
      //Draw a triangle at the end of each line
      float x = t.getX();
      float y = t.getY();
      float heading = t.getHeading();
      
      float[] p1 = getCoords(x, y, 1, heading);
      float[] p2 = getCoords(x, y, 0.5, heading+120);
      float[] p3 = getCoords(x, y, 0.5, heading-120);
      
      fill(0);
      triangle(p1[0], p1[1], p2[0], p2[1], p3[0], p3[1]);
    }
    else if (c == '[') {
      stack.push(new TurtlePos(t.getX(), t.getY(), t.getHeading()));
    }
    else if (c == ']') {
      TurtlePos position = stack.pop();
      t.setX(position.getX());
      t.setY(position.getY());
      t.setHeading(position.getHeading());
    }
    else if (c == '+') {
      t.right(angle);  
    }
    else if (c == '-') {
      t.left(angle);  
    }
  }
}

//Get polar coordinates
float[] getCoords(float x0, float y0, float r, float theta) {
  float[] coords = new float[2];
  coords[0] = x0 + r * cos(radians(theta));
  coords[1] = y0 + r * sin(radians(theta));
 
  return coords;
}
